@@ -110,9 +110,9 @@ public:
 	float CorNorm() const 		 	{ return corNorm_; }
 	float TraNorm() const 		 	{ return traNorm_; }
 
-	float SagPos(int a = 0) const  	{ return sagPos_[a]; }
-	float CorPos(int a = 0) const  	{ return corPos_[a]; }
-	float TraPos(int a = 0) const  	{ return traPos_[a]; }
+	float SagPos(int a = 0) const  	{ return sagPos_.size() > 0 ? sagPos_[a] : columns_ / 2; }
+	float CorPos(int a = 0) const  	{ return corPos_.size() > 0 ? corPos_[a] : rows_ / 2; }
+	float TraPos(int a = 0) const  	{ return traPos_.size() > 0 ? traPos_[a] : 1; }
 
 	bool operator!() const		 	{ return error_; }
 	operator void*() const		 	{ return error_ ? (void *)0 : (void *)this; }
