@@ -76,7 +76,7 @@ DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
 	d3_(false),
 	sliceThickness_(0.0),
 	sliceSpacing_(0.0),
-	acqNum_(0),
+	acqNum_(1),
 	acqEchoNum_(0),
 	columns_(-1),
 	rows_(-1),
@@ -853,18 +853,18 @@ bool DICOMImage::GetACQNumber()
   
    if (GetData(DCM_RELACQUISITIONNUMBER, &strn) == 0)
    {
-	  string msg("DICOMImage::GetACQNumber: Cannot get value of image number in image ");
-	  msg += imgPath_;
-	  cerr << endl << "\t**** " << msg << endl;
-	  error_ = true;
-	  if (strn != NULL) delete [] strn;
-	  return false;
+	   // Defaults to 1
+
+	   COND_PopCondition(TRUE);				// Clear error from stack
    }
+   else
+   {
+	   // Convert string to numerical value
 
-   // Convert string to numerical value
-
-   acqNum_ = atoi(strn);
-   delete [] strn;
+	   acqNum_ = atoi(strn);
+   }
+   
+   if (strn != NULL) delete [] strn;
    return true;
 }
 
@@ -961,34 +961,35 @@ bool DICOMImage::GetImgOrientation()
   
 	if (GetData(DCM_RELIMAGEORIENTATIONPATIENT, &strn) == 0)
 	{
-		string msg("DICOMImage::GetImgOrientation: Cannot get value of patient orientation in image ");
-		msg += imgPath_;
-		cerr << endl << "\t**** " << msg << endl;
-		error_ = true;
-		if (strn != NULL) delete [] strn;
-		return false;
+		// Default to 1,1,1 for both rows and columns
+
+		rowCosines_.assign(3,1);
+		colCosines_.assign(3,1);
+		COND_PopCondition(TRUE);				// Clear error from stack
 	}
+	else
+	{
+		// Convert string to numerical value
+		// Two sets of direction cosines (x, y, z) for first row and first column
+		// with respect to the patient, separated by back slashes.
+		// First set is row values, second the colum values
 
-	// Convert string to numerical value
-	// Two sets of direction cosines (x, y, z) for first row and first column
-	// with respect to the patient, separated by back slashes.
-	// First set is row values, second the colum values
+		char *tok = strtok(strn, "\\");
+		rowCosines_.push_back(atof(tok));
+		tok = strtok(NULL, "\\");
+		rowCosines_.push_back(atof(tok));
+		tok = strtok(NULL, "\\");
+		rowCosines_.push_back(atof(tok));
 
-	char *tok = strtok(strn, "\\");
-	rowCosines_.push_back(atof(tok));
-	tok = strtok(NULL, "\\");
-	rowCosines_.push_back(atof(tok));
-	tok = strtok(NULL, "\\");
-	rowCosines_.push_back(atof(tok));
-
-	tok = strtok(NULL, "\\");
-	colCosines_.push_back(atof(tok));
-	tok = strtok(NULL, "\\");
-	colCosines_.push_back(atof(tok));
-	tok = strtok(NULL, "\\");
-	colCosines_.push_back(atof(tok));
-
-	delete [] strn;
+		tok = strtok(NULL, "\\");
+		colCosines_.push_back(atof(tok));
+		tok = strtok(NULL, "\\");
+		colCosines_.push_back(atof(tok));
+		tok = strtok(NULL, "\\");
+		colCosines_.push_back(atof(tok));
+	}
+	
+	if (strn != NULL) delete [] strn;
 	return true;
 }
 
@@ -1313,7 +1314,7 @@ char *DICOMImage::GetShadowSet()
   
 		while ( startp > 0 )
 		{
-			if ((*strn == '#') && (strncmp(strn, "### ASCCONV END ###", 18) == 0))
+			if ((*strn == '#') && (strncmp(strn, "### ASCCONV END", 15) == 0))
 				break;
 			--strn;
 			--startp;
@@ -1321,7 +1322,7 @@ char *DICOMImage::GetShadowSet()
 
 		while ( startp > 0 )
 		{
-			if ((*strn == '#') && (strncmp(strn, "### ASCCONV BEGIN ###", 21) == 0))
+			if ((*strn == '#') && (strncmp(strn, "### ASCCONV BEGIN", 17) == 0))
 				break;
 			--strn;
 			--startp;
