@@ -5,6 +5,7 @@
 // Modification History (most recent first)
 // mm/dd/yy  Who  What
 //
+// 10/17/11  VPL  Intercept and slope are now computed
 // 04/25/07  VPL  ndim (a.k.a dim[0]) should be 3 for anatomical, 4 for time
 //                series with 1 coil, 5 otherwise.
 // 01/31/07  VPL  Protect against missing images at the beginning of series
@@ -233,8 +234,8 @@ bool NIfTICreateHeader(nifti_image &hdr, IMAGEMAP &imageMap)
 	hdr.dv = 1.0;
 	hdr.dw = 1.0;
 
-	hdr.scl_slope = 0;
-	hdr.scl_inter = 0;
+	hdr.scl_slope = image->ImgRescaleSlope();
+	hdr.scl_inter = image->ImgRescaleIntercept();
 
 	hdr.cal_min = 0;
 	hdr.cal_max = 0;
